@@ -1,3 +1,4 @@
+import aiohttp
 from learning_loop_node.status import Status, State
 from fastapi import FastAPI
 import socketio
@@ -5,7 +6,7 @@ import asyncio
 import asyncio
 import os
 from icecream import ic
-
+import learning_loop_node.loop as loop
 
 WEBSOCKET_BASE_URL_DEFAULT = 'ws://backend'
 BASE_PROJECT = 'demo'
@@ -19,28 +20,26 @@ class Node(FastAPI):
     def __init__(self, name: str, uuid: str):
         super().__init__()
         self.ws_url = os.environ.get('WEBSOCKET_BASE_URL', WEBSOCKET_BASE_URL_DEFAULT)
-        self.username = os.environ.get('USERNAME', None)
-        self.password = os.environ.get('PASSWORD', None)
         self.organization = os.environ.get('ORGANIZATION', BASE_ORGANIZATION)
         self.project = os.environ.get('PROJECT', BASE_PROJECT)
 
         self.name = name
         self.uuid = uuid
 
-        self.sio = socketio.AsyncClient(
+        self.sio_client = socketio.AsyncClient(
             reconnection_delay=0,
             request_timeout=0.5,
             # logger=True, engineio_logger=True
         )
         self.reset()
 
-        @self.sio.on('connect')
+        @self.sio_client.on('connect')
         async def on_connect():
             ic('received "on_connect" from constructor event.')
             self.reset()
             await self.update_state(State.Idle)
 
-        @self.sio.on('disconnect')
+        @self.sio_client.on('disconnect')
         async def on_disconnect():
             ic('received "on_disconnect" from constructor event.')
             await self.update_state(State.Offline)
@@ -56,29 +55,39 @@ class Node(FastAPI):
         @self.on_event("shutdown")
         async def shutdown():
             print('received "shutdown" event', flush=True)
-            await self.sio.disconnect()
+            await self.sio_client.disconnect()
 
     def reset(self):
         self.status = Status(id=self.uuid, name=self.name)
 
     async def connect(self):
         try:
-            await self.sio.disconnect()
+            await self.sio_client.disconnect()
         except:
             pass
 
         print('connecting to Learning Loop', flush=True)
         try:
-            await self.sio.connect(f"{self.ws_url}", auth={'username': self.username, 'password': self.password}, socketio_path="/ws/socket.io")
-            print('my sid is', self.sio.sid, flush=True)
+            headers = await loop.instance.get_headers()
+            await self.sio_client.connect(f"{self.ws_url}", headers=headers, socketio_path="/ws/socket.io")
+            print('my sid is', self.sio_client.sid, flush=True)
             print('connected to Learning Loop', flush=True)
         except socketio.exceptions.ConnectionError as e:
             ic(e)
             if 'Already connected' in str(e):
                 print('we are already connected')
+            if 'Connection refused' in str(e):
+                print(f'Could not connect to "{self.ws_url}"')
+            elif 'Unexpected status code' in str(e):
+                print(f'Could not connect to "{self.ws_url}"')
             else:
                 await asyncio.sleep(0.2)
                 await self.connect()
+        except aiohttp.client_exceptions.ClientConnectorError as e:
+            # NOTE can happen when backend is not yet ready
+            ic(e)
+            await asyncio.sleep(0.2)
+            await self.connect()
 
     async def update_state(self, state: State):
         self.status.state = state
